==> component-preannouncement-1.2.6-20190325.133713-21-sources.jar: com/bxm/newidea/cloud/config/PreWebConfiguration.java <==
package com.bxm.newidea.cloud.config;

import com.bxm.newidea.cloud.ribbon.EnvDiscoveryEnabledRule;
import com.bxm.newidea.cloud.web.HttpHeaderHandlerInterceptorAdapter;
import com.bxm.newidea.component.tools.StringUtils;
import com.netflix.client.config.IClientConfig;
import com.netflix.loadbalancer.IRule;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.netflix.ribbon.PropertiesFactory;
import org.springframework.cloud.netflix.ribbon.RibbonClients;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Lazy;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

/**
 * 注册web拦截器
 * @author liujia
 */
@Configuration
@RibbonClients(defaultConfiguration = PreWebConfiguration.class)
public class PreWebConfiguration implements WebMvcConfigurer {

    @Value("${ribbon.client.name:#{null}}")
    private String name;

    @Autowired(required = false)
    private IClientConfig config;

    @Autowired
    private PropertiesFactory propertiesFactory;

    @Bean
    @Lazy
    public IRule ribbonRule() {
        if (StringUtils.isEmpty(this.name)) {
            return null;
        }
        if (this.propertiesFactory.isSet(IRule.class, this.name)) {
            return this.propertiesFactory.get(IRule.class, this.config, this.name);
        }
        // 默认配置
        EnvDiscoveryEnabledRule rule = new EnvDiscoveryEnabledRule();
        rule.initWithNiwsConfig(this.config);
        return rule;
    }

    @Bean
    public HttpHeaderHandlerInterceptorAdapter interceptorAdapter() {
        return new HttpHeaderHandlerInterceptorAdapter();
    }

    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        registry.addInterceptor(interceptorAdapter());
    }
}

==> component-preannouncement-1.2.10-20190527.064020-14-sources.jar: com/bxm/newidea/cloud/config/PreWebConfiguration.java <==
package com.bxm.newidea.cloud.config;

import com.bxm.newidea.cloud.ribbon.EnvDiscoveryEnabledRule;
import com.bxm.newidea.cloud.web.HttpHeaderHandlerInterceptorAdapter;
import com.bxm.newidea.component.tools.StringUtils;
import com.netflix.client.config.IClientConfig;
import com.netflix.loadbalancer.IRule;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.cloud.netflix.ribbon.PropertiesFactory;
import org.springframework.cloud.netflix.ribbon.RibbonClients;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Lazy;
import org.springframework.web.servlet.config.annotation.InterceptorRegistry;
import org.springframework.web.servlet.config.annotation.WebMvcConfigurer;

/**
 * 注册web拦截器
 * @author liujia
 */
@Configuration
@RibbonClients(defaultConfiguration = PreWebConfiguration.class)
public class PreWebConfiguration implements WebMvcConfigurer {

    @Value("${ribbon.client.name:#{null}}")
    private String name;

    @Value("${biz.enable-pre-env:#{null}}")
    private String preEnv;

    @Autowired(required = false)
    private IClientConfig config;

    @Autowired
    private PropertiesFactory propertiesFactory;

    @Bean
    @Lazy
    public IRule ribbonRule() {
        if (StringUtils.isEmpty(this.name)) {
            return null;
        }
        if (this.propertiesFactory.isSet(IRule.class, this.name)) {
            return this.propertiesFactory.get(IRule.class, this.config, this.name);
        }
        // 默认配置
        EnvDiscoveryEnabledRule rule = new EnvDiscoveryEnabledRule();
        rule.initWithNiwsConfig(this.config);
        rule.setPreEnv(Boolean.valueOf(this.preEnv));
        return rule;
    }

    @Bean
    public HttpHeaderHandlerInterceptorAdapter interceptorAdapter() {
        return new HttpHeaderHandlerInterceptorAdapter();
    }

    @Override
    public void addInterceptors(InterceptorRegistry registry) {
        registry.addInterceptor(interceptorAdapter());
    }
}
